@@ -19,7 +19,7 @@ use Image::ExifTool qw(:DataAccess);
 use Image::ExifTool::Canon;
 use Image::ExifTool::Exif;
 
-$VERSION = '1.53';
+$VERSION = '1.55';
 
 sub ProcessCanonCustom($$$);
 sub ProcessCanonCustom2($$$);
@@ -1360,8 +1360,9 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             4 => 'Center-weighted average',
         },
     },
-    0x010c => {
+    0x010c => [{
         Name => 'ShutterSpeedRange',
+        Condition => '$count == 3',
         Count => 3,
         ValueConv => [
             undef,
@@ -1383,9 +1384,38 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             '$val=~m{([\d./]+)} ? eval $1 : 0',
             '$val=~m{([\d./]+)} ? eval $1 : 0',
         ],
-    },
-    0x010d => {
+    },{ # (EOS R)
+        Name => 'ShutterSpeedRange',
+        Condition => '$count == 4',
+        Count => 4,
+        ValueConv => [ # (NC)
+            'exp(-$val/(1600*log(2)))',
+            'exp(-$val/(1600*log(2)))',
+            'exp(-$val/(1600*log(2)))',
+            'exp(-$val/(1600*log(2)))',
+        ],
+        ValueConvInv => [
+            'int(-log($val)*1600*log(2) + 0.5)',
+            'int(-log($val)*1600*log(2) + 0.5)',
+            'int(-log($val)*1600*log(2) + 0.5)',
+            'int(-log($val)*1600*log(2) + 0.5)',
+        ],
+        PrintConv => [ # (NC)
+            '"Manual: Hi " . Image::ExifTool::Exif::PrintExposureTime($val)',
+            '"Lo " . Image::ExifTool::Exif::PrintExposureTime($val)',
+            '"Auto: Hi " . Image::ExifTool::Exif::PrintExposureTime($val)',
+            '"Lo " . Image::ExifTool::Exif::PrintExposureTime($val)',
+        ],
+        PrintConvInv => [
+            '$val=~m{([\d./]+)} ? eval $1 : 0',
+            '$val=~m{([\d./]+)} ? eval $1 : 0',
+            '$val=~m{([\d./]+)} ? eval $1 : 0',
+            '$val=~m{([\d./]+)} ? eval $1 : 0',
+        ],
+    }],
+    0x010d => [{
         Name => 'ApertureRange',
+        Condition => '$count == 3',
         Count => 3,
         ValueConv => [
             undef,
@@ -1407,7 +1437,35 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             '$val=~/([\d.]+)/ ? $1 : 0',
             '$val=~/([\d.]+)/ ? $1 : 0',
         ],
-    },
+    },{ # (EOS R)
+        Name => 'ApertureRange',
+        Condition => '$count == 4',
+        Count => 4,
+        ValueConv => [ # (NC)
+            'exp($val/2400)',
+            'exp($val/2400)',
+            'exp($val/2400)',
+            'exp($val/2400)',
+        ],
+        ValueConvInv => [
+            'int(log($val)*2400) + 0.5)',
+            'int(log($val)*2400) + 0.5)',
+            'int(log($val)*2400) + 0.5)',
+            'int(log($val)*2400) + 0.5)',
+        ],
+        PrintConv => [ # (NC)
+            'sprintf("Manual: Closed %.2g",$val)',
+            'sprintf("Open %.2g",$val)',
+            'sprintf("Auto: Closed %.2g",$val)',
+            'sprintf("Open %.2g",$val)',
+        ],
+        PrintConvInv => [
+            '$val=~/([\d.]+)/ ? $1 : 0',
+            '$val=~/([\d.]+)/ ? $1 : 0',
+            '$val=~/([\d.]+)/ ? $1 : 0',
+            '$val=~/([\d.]+)/ ? $1 : 0',
+        ],
+    }],
     0x010e => {
         Name => 'ApplyShootingMeteringMode',
         Count => 8,
@@ -1481,13 +1539,36 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
         Count => 3,
         PrintConv => [ \%disableEnable ],
     },
-    0x0112 => { # (5DS)
+    0x0112 => [{ # (5DS)
         Name => 'SameExposureForNewAperture',
         PrintConv => {
             0 => 'Disable',
             1 => 'ISO Speed',
             2 => 'Shutter Speed',
         },
+    },{ # (EOS R)
+        Name => 'SameExposureForNewAperture',
+        Notes => 'EOS R',
+        PrintConv => {
+            0 => 'Disable',
+            1 => 'ISO Speed',
+            2 => 'ISO Speed/Shutter Speed',
+            3 => 'Shutter Speed',
+        },
+    }],
+    0x0113 => { # (200D)
+        Name => 'ExposureCompAutoCancel',
+        PrintConv => \%enableDisable,
+    },
+    0x0114 => { # (R)
+        Name => 'AELockMeterModeAfterFocus',
+        # metering modes where AE lock after focus applies:
+        PrintConv => { BITMASK => { # (NC)
+            0 => 'Evaluative',
+            1 => 'Partial',
+            2 => 'Spot',
+            3 => 'Center-weighted',
+        }},
     },
     #### 2a) Image
     0x0201 => {
@@ -2258,17 +2339,42 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             }},
         ],
     },
-    0x710 => { # (M)
+    0x0710 => { # (M)
         Name => 'TrashButtonFunction',
         PrintConv => {
             0 => 'Normal (set center AF point)',
             1 => 'Depth-of-field preview',
         },
     },
-    0x711 => { # (M)
+    0x0711 => { # (M)
         Name => 'ShutterReleaseWithoutLens',
         PrintConv => \%disableEnable,
     },
+    0x0712 => { # (R)
+        Name => 'ControlRingRotation',
+        PrintConv => {
+            0 => 'Normal',
+            1 => 'Reversed',
+        },
+    },
+    0x0713 => { # (R)
+        Name => 'FocusRingRotation',
+        PrintConv => {
+            0 => 'Normal',
+            1 => 'Reversed',
+        },
+    },
+    0x0714 => { # (R)
+        Name => 'RFLensMFFocusRingSensitivity',
+        PrintConv => {
+            0 => 'Varies With Rotation Speed',
+            1 => 'Linked To Rotation Angle',
+        },
+    },
+    0x0715 => { # (R)
+        Name => 'CustomizeDials', # (NC, may be CustomizeM-FnBar)
+        # (too much stuff to decode)
+    },
     #### 4b) Others
     0x080b => [
         {
@@ -2398,6 +2504,10 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
         Name => 'RetractLensOnPowerOff',
         PrintConv => \%enableDisable,
     },
+    0x0815 => { # (R)
+        Name => 'AddIPTCInformation',
+        PrintConv => \%disableEnable,
+    },
 );
 
 #------------------------------------------------------------------------------
@@ -2444,7 +2554,7 @@ sub ProcessCanonCustom2($$$)
         $newTags = $et->GetNewTagInfoHash($tagTablePtr);
         $et->VPrint(0, "  Rewriting CanonCustom2\n");
     } elsif ($verbose) {
-        $et->VerboseDir('CanonCustom2', $count);
+        $et->VerboseDir('CanonCustom2', $count, $len);
     }
     my $pos = $offset + 8;
     my $end = $offset + $size;
@@ -2463,7 +2573,7 @@ sub ProcessCanonCustom2($$$)
             return 0;
         }
         if ($verbose and not $write) {
-            $et->VerboseDir("CanonCustom2 group $recNum", $recCount);
+            $et->VerboseDir("CanonCustom2 group $recNum", $recCount, $recLen);
         }
         my ($i, $num, $tag);
         for ($i=0; $recPos + 8 < $recEnd; ++$i, $recPos+=4*$num) {
@@ -2505,6 +2615,9 @@ sub ProcessCanonCustom2($$$)
         $pos = $recEnd;
     }
     if ($pos != $end) {
+        # Note: a firmware bug in the EOS M5 and M6 stores an incorrect
+        # size for the 2nd CanonCustom2 record, so this message is expected
+        # for these models...
         $et->Warn('Possibly corrupted CanonCustom2 data');
         return 0;
     }
@@ -2640,7 +2753,7 @@ Image::ExifTool to read this information.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
