@@ -30,7 +30,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.64';
+$VERSION = '1.65';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
@@ -717,6 +717,11 @@ my %faceCategories = (
         Writable => 'int16u',
         Groups => { 2 => 'Video' },
     },
+    0x4005 => { #forum9634
+        Name => 'FaceElementSelected', # (could be face or eye)
+        Writable => 'int16u',
+        Count => 4,
+    },
     0x4100 => { #PH
         Name => 'FacesDetected',
         Writable => 'int16u',
